_OldAbstractModel
=================

.. currentmodule:: pykeen.models

.. autoclass:: _OldAbstractModel
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~_OldAbstractModel.regularizer_default
      ~_OldAbstractModel.regularizer_default_kwargs

   .. rubric:: Methods Summary

   .. autosummary::

      ~_OldAbstractModel.collect_regularization_term
      ~_OldAbstractModel.post_forward_pass
      ~_OldAbstractModel.post_parameter_update
      ~_OldAbstractModel.regularize_if_necessary
      ~_OldAbstractModel.score_h
      ~_OldAbstractModel.score_r
      ~_OldAbstractModel.score_t

   .. rubric:: Attributes Documentation

   .. autoattribute:: regularizer_default
   .. autoattribute:: regularizer_default_kwargs

   .. rubric:: Methods Documentation

   .. automethod:: collect_regularization_term
   .. automethod:: post_forward_pass
   .. automethod:: post_parameter_update
   .. automethod:: regularize_if_necessary
   .. automethod:: score_h
   .. automethod:: score_r
   .. automethod:: score_t
